/*
Copyright 2019 The Kubernetes Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package mockautoscaling

import (
	"sync"

	autoscalingtypes "github.com/aws/aws-sdk-go-v2/service/autoscaling/types"
	"k8s.io/kops/util/pkg/awsinterfaces"
)

type MockAutoscaling struct {
	// Mock out interface
	awsinterfaces.AutoScalingAPI

	mutex             sync.Mutex
	Groups            map[string]*autoscalingtypes.AutoScalingGroup
	WarmPoolInstances map[string][]autoscalingtypes.Instance
	LifecycleHooks    map[string]*autoscalingtypes.LifecycleHook
}

var _ awsinterfaces.AutoScalingAPI = &MockAutoscaling{}
